==> xlniuxdata-vipgame-1.0.30-20150929.081848-31-sources.jar: com/xunlei/niux/data/vipgame/dto/vic/CustomerPersonDetailDTO.java <==
package com.xunlei.niux.data.vipgame.dto.vic;


public class CustomerPersonDetailDTO {

    private Long seqId;
	private String uid;
	private Integer vipGrade;
    private String lastPayTime;
    private Long lastModifyAmt;
    private String payGameId;
    private String loginGameId;
    private String lostPay;

    public Long getSeqId() {
        return seqId;
    }

    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }

    public Long getLastModifyAmt() {
        return lastModifyAmt;
    }

    public void setLastModifyAmt(Long lastModifyAmt) {
        this.lastModifyAmt = lastModifyAmt;
    }

    public String getLastPayTime() {
        return lastPayTime;
    }

    public void setLastPayTime(String lastPayTime) {
        this.lastPayTime = lastPayTime;
    }

    public String getLoginGameId() {
        return loginGameId;
    }

    public void setLoginGameId(String loginGameId) {
        this.loginGameId = loginGameId;
    }

    public String getLostPay() {
        return lostPay;
    }

    public void setLostPay(String lostPay) {
        this.lostPay = lostPay;
    }

    public String getPayGameId() {
        return payGameId;
    }

    public void setPayGameId(String payGameId) {
        this.payGameId = payGameId;
    }

    public String getUid() {
        return uid;
    }

    public void setUid(String uid) {
        this.uid = uid;
    }

    public Integer getVipGrade() {
        return vipGrade;
    }

    public void setVipGrade(Integer vipGrade) {
        this.vipGrade = vipGrade;
    }
}

==> xlniuxdata-vipgame-1.0.65-20170103.065824-54-sources.jar: com/xunlei/niux/data/vipgame/dto/vic/CustomerPersonDetailDTO.java <==
package com.xunlei.niux.data.vipgame.dto.vic;


public class CustomerPersonDetailDTO {

    private Long seqId;
	private String uid;
	private Integer vipGrade;
    private String lastPayTime;
    private Long lastModifyAmt;
    private String payGameId;
    private String loginGameId;
    private String lostPay;
    private String lastCaller;
    private String lastCallTime;

    public String getLastCaller() {
        return lastCaller;
    }

    public void setLastCaller(String lastCaller) {
        this.lastCaller = lastCaller;
    }

    public String getLastCallTime() {
        return lastCallTime;
    }

    public void setLastCallTime(String lastCallTime) {
        this.lastCallTime = lastCallTime;
    }

    public Long getSeqId() {
        return seqId;
    }

    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }

    public Long getLastModifyAmt() {
        return lastModifyAmt;
    }

    public void setLastModifyAmt(Long lastModifyAmt) {
        this.lastModifyAmt = lastModifyAmt;
    }

    public String getLastPayTime() {
        return lastPayTime;
    }

    public void setLastPayTime(String lastPayTime) {
        this.lastPayTime = lastPayTime;
    }

    public String getLoginGameId() {
        return loginGameId;
    }

    public void setLoginGameId(String loginGameId) {
        this.loginGameId = loginGameId;
    }

    public String getLostPay() {
        return lostPay;
    }

    public void setLostPay(String lostPay) {
        this.lostPay = lostPay;
    }

    public String getPayGameId() {
        return payGameId;
    }

    public void setPayGameId(String payGameId) {
        this.payGameId = payGameId;
    }

    public String getUid() {
        return uid;
    }

    public void setUid(String uid) {
        this.uid = uid;
    }

    public Integer getVipGrade() {
        return vipGrade;
    }

    public void setVipGrade(Integer vipGrade) {
        this.vipGrade = vipGrade;
    }
}
